import request from '@/utils/request'

// 查询联系人列表
export function listContacts(query) {
    return request({
        url: '/iot/contacts/list',
        method: 'get',
        params: query
    })
}

// 查询联系人详细
export function getContacts(id) {
    return request({
        url: '/iot/contacts/' + id,
        method: 'get'
    })
}

// 新增联系人
export function addContacts(data) {
    return request({
        url: '/iot/contacts',
        method: 'post',
        data: data
    })
}

// 修改联系人
export function updateContacts(data) {
    return request({
        url: '/iot/contacts',
        method: 'put',
        data: data
    })
}

// 删除联系人
export function delContacts(id) {
    return request({
        url: '/iot/contacts/' + id,
        method: 'delete'
    })
}

// 导出联系人
export function exportContacts(query) {
    return request({
        url: '/iot/contacts/export',
        method: 'get',
        params: query
    })
}

// 查询联系人详细
export function getqrcodeUrl(query) {
  return request({
      url: '/iot/contacts/qrcode/url',
      method: 'get',
      params: query
  })
}

// 解绑微信
export function contactsUbind(id) {
  return request({
      url: '/iot/contacts/unbind/' + id,
      method: 'put'
  })
}
